# Contributing to PlasmaPy

Thank you your interest in contributing to PlasmaPy! ✨ The future of the project depends on contributions from the community, so we deeply appreciate it! 🌱

For more information on how to contribute, please check out our [**contributor guide**](https://docs.plasmapy.org/en/latest/contributing/index.html), which has information on:

 - [Getting ready to contribute](https://docs.plasmapy.org/en/latest/contributing/getting_ready.html#getting-ready-to-contribute)
 - The [code contribution workflow](https://docs.plasmapy.org/en/latest/contributing/workflow.html#code-contribution-workflow)
 - Using [`astropy.units`](https://docs.plasmapy.org/en/latest/notebooks/getting_started/units.html#Using-Astropy-Units) and [`plasmapy.particles`](https://docs.plasmapy.org/en/latest/notebooks/getting_started/particles.html#Using-PlasmaPy-Particles)
 - [Coding tips and guidelines](https://docs.plasmapy.org/en/latest/contributing/coding_guide.html#coding-guide)
 - [Writing and building documentation](https://docs.plasmapy.org/en/latest/contributing/doc_guide.html#writing-documentation)
 - [Writing and running tests](https://docs.plasmapy.org/en/latest/contributing/testing_guide.html#testing-guide)
 - [Adding a changelog entry](https://docs.plasmapy.org/en/latest/contributing/changelog_guide.html#adding-a-changelog-entry) (needed except for minor changes)

You can also find us in our [**chat room**](https://docs.plasmapy.org/en/latest/contributing/coding_guide.html) or weekly [**community meetings**](https://www.plasmapy.org/meetings/weekly) & [**office hours**](https://www.plasmapy.org/meetings/office_hours).

We thank you once again!
